Class: Aws::Kinesis::EndpointParameters

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/endpoint_parameters.rb

Overview

Endpoint parameters used to influence endpoints per request.

Constant Summary collapse

PARAM_MAP =
{
  'Region' => :region,
  'UseDualStack' => :use_dual_stack,
  'UseFIPS' => :use_fips,
  'Endpoint' => :endpoint,
  'OperationType' => :operation_type,
  'StreamId' => :stream_id,
  'StreamARN' => :stream_arn,
  'ConsumerARN' => :consumer_arn,
  'ResourceARN' => :resource_arn,
  'ChannelARN' => :channel_arn,
  'AccountId' => :account_id,
  'AccountIdEndpointMode' => :account_id_endpoint_mode,
}.freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options = {}) ⇒ EndpointParameters

Returns a new instance of EndpointParameters.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 107

def initialize(options = {})
  self[:region] = options[:region]
  self[:use_dual_stack] = options[:use_dual_stack]
  self[:use_dual_stack] = false if self[:use_dual_stack].nil?
  self[:use_fips] = options[:use_fips]
  self[:use_fips] = false if self[:use_fips].nil?
  self[:endpoint] = options[:endpoint]
  self[:operation_type] = options[:operation_type]
  self[:stream_id] = options[:stream_id]
  self[:stream_arn] = options[:stream_arn]
  self[:consumer_arn] = options[:consumer_arn]
  self[:resource_arn] = options[:resource_arn]
  self[:channel_arn] = options[:channel_arn]
  self[:account_id] = options[:account_id]
  self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
end

Instance Attribute Details

#account_idstring

The AWS AccountId used for the request.

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#account_id_endpoint_modestring

The AccountId Endpoint Mode.

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#channel_arnstring

The ARN of the Kinesis data channel

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#consumer_arnstring

The ARN of the Kinesis consumer

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#endpointstring

Override the endpoint used to send this request

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#operation_typestring

Internal parameter to distinguish between Control/Data plane API and accordingly generate control/data plane endpoint

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#regionstring

The AWS region used to dispatch the request.

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#resource_arnstring

The ARN of the Kinesis resource

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#stream_arnstring

The ARN of the Kinesis stream

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#stream_idstring

The unique identifier of the Kinesis stream

Returns:

  • (string)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#use_dual_stackboolean

When true, use the dual-stack endpoint. If the configured endpoint does not support dual-stack, dispatching the request MAY return an error.

Returns:

  • (boolean)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

#use_fipsboolean

When true, send this request to the FIPS-compliant regional endpoint. If the configured endpoint does not have a FIPS compliant endpoint, dispatching the request will return an error.

Returns:

  • (boolean)


73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 73

EndpointParameters = Struct.new(
  :region,
  :use_dual_stack,
  :use_fips,
  :endpoint,
  :operation_type,
  :stream_id,
  :stream_arn,
  :consumer_arn,
  :resource_arn,
  :channel_arn,
  :account_id,
  :account_id_endpoint_mode,
) do
  include Aws::Structure

  # @api private
  class << self
    PARAM_MAP = {
      'Region' => :region,
      'UseDualStack' => :use_dual_stack,
      'UseFIPS' => :use_fips,
      'Endpoint' => :endpoint,
      'OperationType' => :operation_type,
      'StreamId' => :stream_id,
      'StreamARN' => :stream_arn,
      'ConsumerARN' => :consumer_arn,
      'ResourceARN' => :resource_arn,
      'ChannelARN' => :channel_arn,
      'AccountId' => :account_id,
      'AccountIdEndpointMode' => :account_id_endpoint_mode,
    }.freeze
  end

  def initialize(options = {})
    self[:region] = options[:region]
    self[:use_dual_stack] = options[:use_dual_stack]
    self[:use_dual_stack] = false if self[:use_dual_stack].nil?
    self[:use_fips] = options[:use_fips]
    self[:use_fips] = false if self[:use_fips].nil?
    self[:endpoint] = options[:endpoint]
    self[:operation_type] = options[:operation_type]
    self[:stream_id] = options[:stream_id]
    self[:stream_arn] = options[:stream_arn]
    self[:consumer_arn] = options[:consumer_arn]
    self[:resource_arn] = options[:resource_arn]
    self[:channel_arn] = options[:channel_arn]
    self[:account_id] = options[:account_id]
    self[:account_id_endpoint_mode] = options[:account_id_endpoint_mode]
  end

  def self.create(config, options={})
    new({
      region: config.region,
      use_dual_stack: config.use_dualstack_endpoint,
      use_fips: config.use_fips_endpoint,
      endpoint: (config.endpoint.to_s unless config.regional_endpoint),
      account_id: config.credentials.credentials.,
      account_id_endpoint_mode: config.,
    }.merge(options))
  end
end

Class Method Details

.create(config, options = {}) ⇒ Object



124
125
126
127
128
129
130
131
132
133
# File 'lib/aws-sdk-kinesis/endpoint_parameters.rb', line 124

def self.create(config, options={})
  new({
    region: config.region,
    use_dual_stack: config.use_dualstack_endpoint,
    use_fips: config.use_fips_endpoint,
    endpoint: (config.endpoint.to_s unless config.regional_endpoint),
    account_id: config.credentials.credentials.,
    account_id_endpoint_mode: config.,
  }.merge(options))
end