Class: Aws::Kinesis::Types::ChannelDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ChannelDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Describes the configuration and current status of a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The Amazon Resource Name (ARN) of the channel.
-
#channel_creation_timestamp ⇒ Time
The time at which the channel was created.
-
#channel_id ⇒ String
The unique identifier of the channel.
-
#channel_name ⇒ String
The name of the channel.
-
#channel_status ⇒ String
The current status of the channel.
-
#channel_status_reason ⇒ String
A message describing the reason for a
FAILEDstatus. -
#encryption_configuration ⇒ Types::ChannelEncryptionConfiguration
The server-side encryption configuration for the channel.
-
#logging_configuration ⇒ Types::ChannelLoggingConfiguration
The Amazon CloudWatch Logs configuration for the channel.
-
#s3_destination_configuration ⇒ Types::S3DestinationDescription
The configuration for delivery to a general purpose Amazon S3 bucket.
-
#s3_tables_destination_configuration ⇒ Types::S3TablesDestinationDescription
The configuration for delivery to streaming tables on Apache Iceberg in Amazon S3 Tables.
-
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Data Streams assumes to write records to the destination.
-
#stream_configuration_list ⇒ Array<Types::ChannelStreamDescription>
The source stream configuration for the channel.
Instance Attribute Details
#channel_arn ⇒ String
The Amazon Resource Name (ARN) of the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_creation_timestamp ⇒ Time
The time at which the channel was created.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_id ⇒ String
The unique identifier of the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_name ⇒ String
The name of the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_status ⇒ String
The current status of the channel. Valid values:
-
CREATING -
ACTIVE -
UPDATING -
DELETING -
FAILED- SeeChannelStatusReasonfor the failure cause.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#channel_status_reason ⇒ String
A message describing the reason for a FAILED status.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::ChannelEncryptionConfiguration
The server-side encryption configuration for the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ChannelLoggingConfiguration
The Amazon CloudWatch Logs configuration for the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_destination_configuration ⇒ Types::S3DestinationDescription
The configuration for delivery to a general purpose Amazon S3 bucket. Present only when the channel destination is a general purpose Amazon S3 bucket.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_tables_destination_configuration ⇒ Types::S3TablesDestinationDescription
The configuration for delivery to streaming tables on Apache Iceberg in Amazon S3 Tables. Present only when the channel destination is a streaming table.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#service_execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Data Streams assumes to write records to the destination.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_configuration_list ⇒ Array<Types::ChannelStreamDescription>
The source stream configuration for the channel.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 125 class ChannelDescription < Struct.new( :channel_name, :channel_arn, :channel_id, :channel_status, :channel_status_reason, :channel_creation_timestamp, :service_execution_role_arn, :stream_configuration_list, :s3_destination_configuration, :s3_tables_destination_configuration, :encryption_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |