Class: Aws::Kinesis::Types::ChannelEncryptionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

The server-side encryption configuration for a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_typeString

The encryption type. The only valid value is KMS.

Returns:

  • (String)


156
157
158
159
160
161
# File 'lib/aws-sdk-kinesis/types.rb', line 156

class ChannelEncryptionConfiguration < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The identifier of the customer managed Amazon Web Services KMS key. You cannot use the Amazon Kinesis Data Streams service key (aws/kinesis).

Returns:

  • (String)


156
157
158
159
160
161
# File 'lib/aws-sdk-kinesis/types.rb', line 156

class ChannelEncryptionConfiguration < Struct.new(
  :encryption_type,
  :key_id)
  SENSITIVE = []
  include Aws::Structure
end