Class: Aws::Kinesis::Types::ChannelStreamDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ChannelStreamDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Describes the source stream of a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#record_configuration ⇒ Types::RecordConfiguration
The record format configuration for the source stream.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the source Kinesis data stream.
-
#stream_creation_timestamp ⇒ Time
The time at which the source stream was created.
Instance Attribute Details
#record_configuration ⇒ Types::RecordConfiguration
The record format configuration for the source stream.
228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-kinesis/types.rb', line 228 class ChannelStreamDescription < Struct.new( :stream_arn, :stream_creation_timestamp, :record_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the source Kinesis data stream.
228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-kinesis/types.rb', line 228 class ChannelStreamDescription < Struct.new( :stream_arn, :stream_creation_timestamp, :record_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_creation_timestamp ⇒ Time
The time at which the source stream was created.
228 229 230 231 232 233 234 |
# File 'lib/aws-sdk-kinesis/types.rb', line 228 class ChannelStreamDescription < Struct.new( :stream_arn, :stream_creation_timestamp, :record_configuration) SENSITIVE = [] include Aws::Structure end |