Class: Aws::Kinesis::Types::ChannelStreamIdentifier
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ChannelStreamIdentifier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Identifies a source stream associated with a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the source Kinesis data stream.
-
#stream_creation_timestamp ⇒ Time
The time at which the source stream was created.
Instance Attribute Details
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the source Kinesis data stream.
248 249 250 251 252 253 |
# File 'lib/aws-sdk-kinesis/types.rb', line 248 class ChannelStreamIdentifier < Struct.new( :stream_arn, :stream_creation_timestamp) SENSITIVE = [] include Aws::Structure end |
#stream_creation_timestamp ⇒ Time
The time at which the source stream was created.
248 249 250 251 252 253 |
# File 'lib/aws-sdk-kinesis/types.rb', line 248 class ChannelStreamIdentifier < Struct.new( :stream_arn, :stream_creation_timestamp) SENSITIVE = [] include Aws::Structure end |