Class: Aws::Kinesis::Types::Consumer
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::Consumer
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
An object that represents the details of the consumer you registered. This type of object is returned by RegisterStreamConsumer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_arn ⇒ String
When you register a consumer, Kinesis Data Streams generates an ARN for it.
- #consumer_creation_timestamp ⇒ Time
-
#consumer_name ⇒ String
The name of the consumer is something you choose when you register the consumer.
-
#consumer_status ⇒ String
A consumer can't read data while in the
CREATINGorDELETINGstates.
Instance Attribute Details
#consumer_arn ⇒ String
When you register a consumer, Kinesis Data Streams generates an ARN for it. You need this ARN to be able to call SubscribeToShard.
If you delete a consumer and then create a new one with the same name, it won't have the same ARN. That's because consumer ARNs contain the creation timestamp. This is important to keep in mind if you have IAM policies that reference consumer ARNs.
422 423 424 425 426 427 428 429 |
# File 'lib/aws-sdk-kinesis/types.rb', line 422 class Consumer < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp) SENSITIVE = [] include Aws::Structure end |
#consumer_creation_timestamp ⇒ Time
422 423 424 425 426 427 428 429 |
# File 'lib/aws-sdk-kinesis/types.rb', line 422 class Consumer < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp) SENSITIVE = [] include Aws::Structure end |
#consumer_name ⇒ String
The name of the consumer is something you choose when you register the consumer.
422 423 424 425 426 427 428 429 |
# File 'lib/aws-sdk-kinesis/types.rb', line 422 class Consumer < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp) SENSITIVE = [] include Aws::Structure end |
#consumer_status ⇒ String
A consumer can't read data while in the CREATING or DELETING
states.
422 423 424 425 426 427 428 429 |
# File 'lib/aws-sdk-kinesis/types.rb', line 422 class Consumer < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp) SENSITIVE = [] include Aws::Structure end |