Class: Aws::Kinesis::Types::ConsumerDescription

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

An object that represents the details of a registered consumer. This type of object is returned by DescribeStreamConsumer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_arnString

When you register a consumer, Kinesis Data Streams generates an ARN for it. You need this ARN to be able to call SubscribeToShard.

If you delete a consumer and then create a new one with the same name, it won't have the same ARN. That's because consumer ARNs contain the creation timestamp. This is important to keep in mind if you have IAM policies that reference consumer ARNs.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
# File 'lib/aws-sdk-kinesis/types.rb', line 463

class ConsumerDescription < Struct.new(
  :consumer_name,
  :consumer_arn,
  :consumer_status,
  :consumer_creation_timestamp,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_creation_timestampTime

Returns:

  • (Time)


463
464
465
466
467
468
469
470
471
# File 'lib/aws-sdk-kinesis/types.rb', line 463

class ConsumerDescription < Struct.new(
  :consumer_name,
  :consumer_arn,
  :consumer_status,
  :consumer_creation_timestamp,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_nameString

The name of the consumer is something you choose when you register the consumer.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
# File 'lib/aws-sdk-kinesis/types.rb', line 463

class ConsumerDescription < Struct.new(
  :consumer_name,
  :consumer_arn,
  :consumer_status,
  :consumer_creation_timestamp,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_statusString

A consumer can't read data while in the CREATING or DELETING states.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
# File 'lib/aws-sdk-kinesis/types.rb', line 463

class ConsumerDescription < Struct.new(
  :consumer_name,
  :consumer_arn,
  :consumer_status,
  :consumer_creation_timestamp,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The ARN of the stream with which you registered the consumer.

Returns:

  • (String)


463
464
465
466
467
468
469
470
471
# File 'lib/aws-sdk-kinesis/types.rb', line 463

class ConsumerDescription < Struct.new(
  :consumer_name,
  :consumer_arn,
  :consumer_status,
  :consumer_creation_timestamp,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end