Class: Aws::Kinesis::Types::CreateChannelInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_nameString

The name of the channel. The name is unique within your Amazon Web Services account and Amazon Web Services Region.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::ChannelEncryptionConfiguration

The server-side encryption configuration that uses an Amazon Web Services KMS key to encrypt data delivered to the destination.



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::ChannelLoggingConfiguration

The Amazon CloudWatch Logs configuration for the channel.



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#s3_destination_configurationTypes::S3DestinationConfiguration

The configuration for delivery to a general purpose Amazon S3 bucket. You must specify either S3DestinationConfiguration or S3TablesDestinationConfiguration, but not both.



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#s3_tables_destination_configurationTypes::S3TablesDestinationConfiguration

The configuration for delivery to streaming tables on Apache Iceberg in Amazon S3 Tables. You must specify either S3DestinationConfiguration or S3TablesDestinationConfiguration, but not both.



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#service_execution_role_arnString

The Amazon Resource Name (ARN) of the IAM role that Amazon Kinesis Data Streams assumes to write records to the destination.

Returns:

  • (String)


517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stream_configuration_listArray<Types::ChannelStreamConfiguration>

The source stream configuration for the channel. Currently, one stream is supported per channel.



517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A set of key-value pairs to assign to the channel. A tag consists of a required key and an optional value.

Returns:

  • (Hash<String,String>)


517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/aws-sdk-kinesis/types.rb', line 517

class CreateChannelInput < Struct.new(
  :channel_name,
  :service_execution_role_arn,
  :stream_configuration_list,
  :s3_destination_configuration,
  :s3_tables_destination_configuration,
  :encryption_configuration,
  :tags,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end