Class: Aws::Kinesis::Types::DeleteStreamInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::DeleteStreamInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the input for DeleteStream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enforce_consumer_deletion ⇒ Boolean
If this parameter is unset (
null) or if you set it tofalse, and the stream has registered consumers, the call toDeleteStreamfails with aResourceInUseException. -
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the stream to delete.
Instance Attribute Details
#enforce_consumer_deletion ⇒ Boolean
If this parameter is unset (null) or if you set it to false, and
the stream has registered consumers, the call to DeleteStream
fails with a ResourceInUseException.
703 704 705 706 707 708 709 710 |
# File 'lib/aws-sdk-kinesis/types.rb', line 703 class DeleteStreamInput < Struct.new( :stream_name, :enforce_consumer_deletion, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
703 704 705 706 707 708 709 710 |
# File 'lib/aws-sdk-kinesis/types.rb', line 703 class DeleteStreamInput < Struct.new( :stream_name, :enforce_consumer_deletion, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
703 704 705 706 707 708 709 710 |
# File 'lib/aws-sdk-kinesis/types.rb', line 703 class DeleteStreamInput < Struct.new( :stream_name, :enforce_consumer_deletion, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream to delete.
703 704 705 706 707 708 709 710 |
# File 'lib/aws-sdk-kinesis/types.rb', line 703 class DeleteStreamInput < Struct.new( :stream_name, :enforce_consumer_deletion, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |