Class: Aws::Kinesis::Types::DescribeLimitsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::DescribeLimitsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_count ⇒ Integer
The number of channels in the account.
-
#channel_count_limit ⇒ Integer
The maximum number of channels allowed in the account.
-
#on_demand_stream_count ⇒ Integer
Indicates the number of data streams with the on-demand capacity mode.
-
#on_demand_stream_count_limit ⇒ Integer
The maximum number of data streams with the on-demand capacity mode.
-
#open_shard_count ⇒ Integer
The number of open shards.
-
#shard_limit ⇒ Integer
The maximum number of shards.
Instance Attribute Details
#channel_count ⇒ Integer
The number of channels in the account.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |
#channel_count_limit ⇒ Integer
The maximum number of channels allowed in the account.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |
#on_demand_stream_count ⇒ Integer
Indicates the number of data streams with the on-demand capacity mode.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |
#on_demand_stream_count_limit ⇒ Integer
The maximum number of data streams with the on-demand capacity mode.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |
#open_shard_count ⇒ Integer
The number of open shards.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |
#shard_limit ⇒ Integer
The maximum number of shards.
826 827 828 829 830 831 832 833 834 835 |
# File 'lib/aws-sdk-kinesis/types.rb', line 826 class DescribeLimitsOutput < Struct.new( :shard_limit, :open_shard_count, :on_demand_stream_count, :on_demand_stream_count_limit, :channel_count, :channel_count_limit) SENSITIVE = [] include Aws::Structure end |