Class: Aws::Kinesis::Types::DescribeStreamConsumerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_arnString

The ARN returned by Kinesis Data Streams when you registered the consumer.

Returns:

  • (String)


862
863
864
865
866
867
868
869
# File 'lib/aws-sdk-kinesis/types.rb', line 862

class DescribeStreamConsumerInput < Struct.new(
  :stream_arn,
  :consumer_name,
  :consumer_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_nameString

The name that you gave to the consumer.

Returns:

  • (String)


862
863
864
865
866
867
868
869
# File 'lib/aws-sdk-kinesis/types.rb', line 862

class DescribeStreamConsumerInput < Struct.new(
  :stream_arn,
  :consumer_name,
  :consumer_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces.

Returns:

  • (String)


862
863
864
865
866
867
868
869
# File 'lib/aws-sdk-kinesis/types.rb', line 862

class DescribeStreamConsumerInput < Struct.new(
  :stream_arn,
  :consumer_name,
  :consumer_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


862
863
864
865
866
867
868
869
# File 'lib/aws-sdk-kinesis/types.rb', line 862

class DescribeStreamConsumerInput < Struct.new(
  :stream_arn,
  :consumer_name,
  :consumer_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end