Class: Aws::Kinesis::Types::DescribeStreamInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::DescribeStreamInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the input for DescribeStream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclusive_start_shard_id ⇒ String
The shard ID of the shard to start with.
-
#limit ⇒ Integer
The maximum number of shards to return in a single call.
-
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the stream to describe.
Instance Attribute Details
#exclusive_start_shard_id ⇒ String
The shard ID of the shard to start with.
Specify this parameter to indicate that you want to describe the
stream starting with the shard whose ID immediately follows
ExclusiveStartShardId.
If you don't specify this parameter, the default behavior for
DescribeStream is to describe the stream starting with the first
shard in the stream.
917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kinesis/types.rb', line 917 class DescribeStreamInput < Struct.new( :stream_name, :limit, :exclusive_start_shard_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of shards to return in a single call. The default value is 100. If you specify a value greater than 100, at most 100 results are returned.
917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kinesis/types.rb', line 917 class DescribeStreamInput < Struct.new( :stream_name, :limit, :exclusive_start_shard_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kinesis/types.rb', line 917 class DescribeStreamInput < Struct.new( :stream_name, :limit, :exclusive_start_shard_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kinesis/types.rb', line 917 class DescribeStreamInput < Struct.new( :stream_name, :limit, :exclusive_start_shard_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream to describe.
917 918 919 920 921 922 923 924 925 |
# File 'lib/aws-sdk-kinesis/types.rb', line 917 class DescribeStreamInput < Struct.new( :stream_name, :limit, :exclusive_start_shard_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |