Class: Aws::Kinesis::Types::EnableEnhancedMonitoringInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::EnableEnhancedMonitoringInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the input for EnableEnhancedMonitoring.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics to enable.
-
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the stream for which to enable enhanced monitoring.
Instance Attribute Details
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics to enable.
The following are the valid shard-level metrics. The value “ALL” enables every metric.
-
IncomingBytes -
IncomingRecords -
OutgoingBytes -
OutgoingRecords -
WriteProvisionedThroughputExceeded -
ReadProvisionedThroughputExceeded -
IteratorAgeMilliseconds -
ALL
For more information, see [Monitoring the Amazon Kinesis Data Streams Service with Amazon CloudWatch][1] in the *Amazon Kinesis Data Streams Developer Guide*.
[1]: docs.aws.amazon.com/kinesis/latest/dev/monitoring-with-cloudwatch.html
629 630 631 632 633 634 635 636 |
# File 'lib/aws-sdk-kinesis/types.rb', line 629 class EnableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
629 630 631 632 633 634 635 636 |
# File 'lib/aws-sdk-kinesis/types.rb', line 629 class EnableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
629 630 631 632 633 634 635 636 |
# File 'lib/aws-sdk-kinesis/types.rb', line 629 class EnableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream for which to enable enhanced monitoring.
629 630 631 632 633 634 635 636 |
# File 'lib/aws-sdk-kinesis/types.rb', line 629 class EnableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |