Class: Aws::Kinesis::Types::EnhancedMetrics
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::EnhancedMetrics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents enhanced metrics types.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics.
Instance Attribute Details
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics.
The following are the valid shard-level metrics. The value "ALL"
enhances every metric.
-
IncomingBytes -
IncomingRecords -
OutgoingBytes -
OutgoingRecords -
WriteProvisionedThroughputExceeded -
ReadProvisionedThroughputExceeded -
IteratorAgeMilliseconds -
ALL
For more information, see Monitoring the Amazon Kinesis Data Streams Service with Amazon CloudWatch in the Amazon Kinesis Data Streams Developer Guide.
673 674 675 676 677 |
# File 'lib/aws-sdk-kinesis/types.rb', line 673 class EnhancedMetrics < Struct.new( :shard_level_metrics) SENSITIVE = [] include Aws::Structure end |