Class: Aws::Kinesis::Types::EnhancedMonitoringOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::EnhancedMonitoringOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the output for EnableEnhancedMonitoring and DisableEnhancedMonitoring.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_shard_level_metrics ⇒ Array<String>
Represents the current state of the metrics that are in the enhanced state before the operation.
-
#desired_shard_level_metrics ⇒ Array<String>
Represents the list of all the metrics that would be in the enhanced state after the operation.
-
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_name ⇒ String
The name of the Kinesis data stream.
Instance Attribute Details
#current_shard_level_metrics ⇒ Array<String>
Represents the current state of the metrics that are in the enhanced state before the operation.
1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1154 class EnhancedMonitoringOutput < Struct.new( :stream_name, :current_shard_level_metrics, :desired_shard_level_metrics, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#desired_shard_level_metrics ⇒ Array<String>
Represents the list of all the metrics that would be in the enhanced state after the operation.
1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1154 class EnhancedMonitoringOutput < Struct.new( :stream_name, :current_shard_level_metrics, :desired_shard_level_metrics, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1154 class EnhancedMonitoringOutput < Struct.new( :stream_name, :current_shard_level_metrics, :desired_shard_level_metrics, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the Kinesis data stream.
1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1154 class EnhancedMonitoringOutput < Struct.new( :stream_name, :current_shard_level_metrics, :desired_shard_level_metrics, :stream_arn) SENSITIVE = [] include Aws::Structure end |