Class: Aws::Kinesis::Types::GetShardIteratorInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the input for GetShardIterator.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dry_runBoolean

Checks if your request will succeed. DryRun is an optional parameter.

Returns:

  • (Boolean)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#shard_idString

The shard ID of the Kinesis Data Streams shard to get the iterator for.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#shard_iterator_typeString

Determines how the shard iterator is used to start reading data records from the shard.

The following are the valid Amazon Kinesis shard iterator types:

  • AT_SEQUENCE_NUMBER - Start reading from the position denoted by a specific sequence number, provided in the value StartingSequenceNumber.

  • AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number, provided in the value StartingSequenceNumber.

  • AT_TIMESTAMP - Start reading from the position denoted by a specific time stamp, provided in the value Timestamp.

  • TRIM_HORIZON - Start reading at the last untrimmed record in the shard in the system, which is the oldest data record in the shard.

  • LATEST - Start reading just after the most recent record in the shard, so that you always read the most recent data in the shard.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#starting_sequence_numberString

The sequence number of the data record in the shard from which to start reading. Used with shard iterator type AT_SEQUENCE_NUMBER and AFTER_SEQUENCE_NUMBER.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The ARN of the stream.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the Amazon Kinesis data stream.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The time stamp of the data record from which to start reading. Used with shard iterator type AT_TIMESTAMP. A time stamp is the Unix epoch date with precision in milliseconds. For example, 2016-04-04T19:58:46.480-00:00 or 1459799926.480. If a record with this exact time stamp does not exist, the iterator returned is for the next (later) record. If the time stamp is older than the current trim horizon, the iterator returned is for the oldest untrimmed data record (TRIM_HORIZON).

Returns:

  • (Time)


1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
# File 'lib/aws-sdk-kinesis/types.rb', line 1376

class GetShardIteratorInput < Struct.new(
  :stream_name,
  :shard_id,
  :shard_iterator_type,
  :starting_sequence_number,
  :timestamp,
  :stream_arn,
  :stream_id,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end