Class: Aws::Kinesis::Types::KMSInvalidStateException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

The request was rejected because the state of the specified resource isn't valid for this request. For more information, see How Key State Affects Use of a Customer Master Key in the Amazon Web Services Key Management Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



1506
1507
1508
# File 'lib/aws-sdk-kinesis/types.rb', line 1506

def event_type
  @event_type
end

#messageString

A message that provides information about the error.

Returns:

  • (String)


1506
1507
1508
1509
1510
1511
# File 'lib/aws-sdk-kinesis/types.rb', line 1506

class KMSInvalidStateException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end