Class: Aws::Kinesis::Types::KMSThrottlingException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

The request was denied due to request throttling. For more information about throttling, see Limits in the Amazon Web Services Key Management Service Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_typeObject

Returns the value of attribute event_type

Returns:

  • (Object)

    the current value of event_type



1559
1560
1561
# File 'lib/aws-sdk-kinesis/types.rb', line 1559

def event_type
  @event_type
end

#messageString

A message that provides information about the error.

Returns:

  • (String)


1559
1560
1561
1562
1563
1564
# File 'lib/aws-sdk-kinesis/types.rb', line 1559

class KMSThrottlingException < Struct.new(
  :message,
  :event_type)
  SENSITIVE = []
  include Aws::Structure
end