Class: Aws::Kinesis::Types::ListChannelsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of channels to return in a single call. The default value is 100. If you specify a value greater than 100, at most 100 results are returned.



1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-kinesis/types.rb', line 1627

class ListChannelsInput < Struct.new(
  :stream_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token returned by a previous call. Specify this token to retrieve the next page of results. This value is null when there are no more results to return.



1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-kinesis/types.rb', line 1627

class ListChannelsInput < Struct.new(
  :stream_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#stream_filterArray<Types::StreamFilter>

Filters the results to channels associated with the specified streams.



1627
1628
1629
1630
1631
1632
1633
# File 'lib/aws-sdk-kinesis/types.rb', line 1627

class ListChannelsInput < Struct.new(
  :stream_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end