Class: Aws::Kinesis::Types::ListChannelsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_summariesArray<Types::ChannelSummary>

A list of channel summaries.

Returns:



1647
1648
1649
1650
1651
1652
# File 'lib/aws-sdk-kinesis/types.rb', line 1647

class ListChannelsOutput < Struct.new(
  :channel_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use in a subsequent call to retrieve the next page of results. This value is null when there are no more results to return.

Returns:

  • (String)


1647
1648
1649
1650
1651
1652
# File 'lib/aws-sdk-kinesis/types.rb', line 1647

class ListChannelsOutput < Struct.new(
  :channel_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end