Class: Aws::Kinesis::Types::ListShardsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ListShardsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#exclusive_start_shard_id ⇒ String
Specify this parameter to indicate that you want to list the shards starting with the shard whose ID immediately follows
ExclusiveStartShardId. -
#max_results ⇒ Integer
The maximum number of shards to return in a single call to
ListShards. -
#next_token ⇒ String
When the number of shards in the data stream is greater than the default value for the
MaxResultsparameter, or if you explicitly specify a value forMaxResultsthat is less than the number of shards in the data stream, the response includes a pagination token namedNextToken. -
#shard_filter ⇒ Types::ShardFilter
Enables you to filter out the response of the
ListShardsAPI. -
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_creation_timestamp ⇒ Time
Specify this input parameter to distinguish data streams that have the same name.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the data stream whose shards you want to list.
Instance Attribute Details
#exclusive_start_shard_id ⇒ String
Specify this parameter to indicate that you want to list the shards
starting with the shard whose ID immediately follows
ExclusiveStartShardId.
If you don't specify this parameter, the default behavior is for
ListShards to list the shards starting with the first one in the
stream.
You cannot specify this parameter if you specify NextToken.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of shards to return in a single call to
ListShards. The maximum number of shards to return in a single
call. The default value is 1000. If you specify a value greater than
1000, at most 1000 results are returned.
When the number of shards to be listed is greater than the value of
MaxResults, the response contains a NextToken value that you can
use in a subsequent call to ListShards to list the next set of
shards.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When the number of shards in the data stream is greater than the
default value for the MaxResults parameter, or if you explicitly
specify a value for MaxResults that is less than the number of
shards in the data stream, the response includes a pagination token
named NextToken. You can specify this NextToken value in a
subsequent call to ListShards to list the next set of shards.
Don't specify StreamName or StreamCreationTimestamp if you
specify NextToken because the latter unambiguously identifies the
stream.
You can optionally specify a value for the MaxResults parameter
when you specify NextToken. If you specify a MaxResults value
that is less than the number of shards that the operation returns if
you don't specify MaxResults, the response will contain a new
NextToken value. You can use the new NextToken value in a
subsequent call to the ListShards operation.
Tokens expire after 300 seconds. When you obtain a value for
NextToken in the response to a call to ListShards, you have 300
seconds to use that value. If you specify an expired token in a call
to ListShards, you get ExpiredNextTokenException.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#shard_filter ⇒ Types::ShardFilter
Enables you to filter out the response of the ListShards API. You
can only specify one filter at a time.
If you use the ShardFilter parameter when invoking the ListShards
API, the Type is the required property and must be specified. If
you specify the AT_TRIM_HORIZON, FROM_TRIM_HORIZON, or
AT_LATEST types, you do not need to specify either the ShardId
or the Timestamp optional properties.
If you specify the AFTER_SHARD_ID type, you must also provide the
value for the optional ShardId property. The ShardId property is
identical in fuctionality to the ExclusiveStartShardId parameter
of the ListShards API. When ShardId property is specified, the
response includes the shards starting with the shard whose ID
immediately follows the ShardId that you provided.
If you specify the AT_TIMESTAMP or FROM_TIMESTAMP_ID type, you
must also provide the value for the optional Timestamp property.
If you specify the AT_TIMESTAMP type, then all shards that were
open at the provided timestamp are returned. If you specify the
FROM_TIMESTAMP type, then all shards starting from the provided
timestamp to TIP are returned.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_creation_timestamp ⇒ Time
Specify this input parameter to distinguish data streams that have the same name. For example, if you create a data stream and then delete it, and you later create another data stream with the same name, you can use this input parameter to specify which of the two streams you want to list the shards for.
You cannot specify this parameter if you specify the NextToken
parameter.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the data stream whose shards you want to list.
You cannot specify this parameter if you specify the NextToken
parameter.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1756 class ListShardsInput < Struct.new( :stream_name, :next_token, :exclusive_start_shard_id, :max_results, :stream_creation_timestamp, :shard_filter, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |