Class: Aws::Kinesis::Types::ListStreamConsumersOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ListStreamConsumersOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumers ⇒ Array<Types::Consumer>
An array of JSON objects.
-
#next_token ⇒ String
When the number of consumers that are registered with the data stream is greater than the default value for the
MaxResultsparameter, or if you explicitly specify a value forMaxResultsthat is less than the number of registered consumers, the response includes a pagination token namedNextToken.
Instance Attribute Details
#consumers ⇒ Array<Types::Consumer>
An array of JSON objects. Each object represents one registered consumer.
1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1376 class ListStreamConsumersOutput < Struct.new( :consumers, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
When the number of consumers that are registered with the data stream is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of registered consumers, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListStreamConsumers to list the next set of registered consumers. For more information about the use of this pagination token when calling the ListStreamConsumers operation, see ListStreamConsumersInput$NextToken.
Tokens expire after 300 seconds. When you obtain a value for NextToken in the response to a call to ListStreamConsumers, you have 300 seconds to use that value. If you specify an expired token in a call to ListStreamConsumers, you get ExpiredNextTokenException.
1376 1377 1378 1379 1380 1381 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1376 class ListStreamConsumersOutput < Struct.new( :consumers, :next_token) SENSITIVE = [] include Aws::Structure end |