Class: Aws::Kinesis::Types::ListStreamsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the output for ListStreams.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#has_more_streamsBoolean

If set to true, there are more streams available to list.

Returns:

  • (Boolean)


1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-kinesis/types.rb', line 1951

class ListStreamsOutput < Struct.new(
  :stream_names,
  :has_more_streams,
  :next_token,
  :stream_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Returns:

  • (String)


1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-kinesis/types.rb', line 1951

class ListStreamsOutput < Struct.new(
  :stream_names,
  :has_more_streams,
  :next_token,
  :stream_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#stream_namesArray<String>

The names of the streams that are associated with the Amazon Web Services account making the ListStreams request.

Returns:

  • (Array<String>)


1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-kinesis/types.rb', line 1951

class ListStreamsOutput < Struct.new(
  :stream_names,
  :has_more_streams,
  :next_token,
  :stream_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#stream_summariesArray<Types::StreamSummary>

Returns:



1951
1952
1953
1954
1955
1956
1957
1958
# File 'lib/aws-sdk-kinesis/types.rb', line 1951

class ListStreamsOutput < Struct.new(
  :stream_names,
  :has_more_streams,
  :next_token,
  :stream_summaries)
  SENSITIVE = []
  include Aws::Structure
end