Class: Aws::Kinesis::Types::MinimumThroughputBillingCommitmentOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the current status of minimum throughput billing commitment for an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#earliest_allowed_end_atTime

The earliest timestamp when the commitment can be ended.

Returns:

  • (Time)


2112
2113
2114
2115
2116
2117
2118
2119
# File 'lib/aws-sdk-kinesis/types.rb', line 2112

class MinimumThroughputBillingCommitmentOutput < Struct.new(
  :status,
  :started_at,
  :ended_at,
  :earliest_allowed_end_at)
  SENSITIVE = []
  include Aws::Structure
end

#ended_atTime

The timestamp when the commitment was ended.

Returns:

  • (Time)


2112
2113
2114
2115
2116
2117
2118
2119
# File 'lib/aws-sdk-kinesis/types.rb', line 2112

class MinimumThroughputBillingCommitmentOutput < Struct.new(
  :status,
  :started_at,
  :ended_at,
  :earliest_allowed_end_at)
  SENSITIVE = []
  include Aws::Structure
end

#started_atTime

The timestamp when the commitment was started.

Returns:

  • (Time)


2112
2113
2114
2115
2116
2117
2118
2119
# File 'lib/aws-sdk-kinesis/types.rb', line 2112

class MinimumThroughputBillingCommitmentOutput < Struct.new(
  :status,
  :started_at,
  :ended_at,
  :earliest_allowed_end_at)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the minimum throughput billing commitment.

Returns:

  • (String)


2112
2113
2114
2115
2116
2117
2118
2119
# File 'lib/aws-sdk-kinesis/types.rb', line 2112

class MinimumThroughputBillingCommitmentOutput < Struct.new(
  :status,
  :started_at,
  :ended_at,
  :earliest_allowed_end_at)
  SENSITIVE = []
  include Aws::Structure
end