Class: Aws::Kinesis::Types::PartitionField
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::PartitionField
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Specifies a single partition field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_name ⇒ String
The name of the source column used for partitioning.
-
#transform ⇒ String
The partition transform to apply.
Instance Attribute Details
#source_name ⇒ String
The name of the source column used for partitioning. This column
must be of the timestamptz type.
2135 2136 2137 2138 2139 2140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2135 class PartitionField < Struct.new( :transform, :source_name) SENSITIVE = [] include Aws::Structure end |
#transform ⇒ String
The partition transform to apply. The only valid value is
TIME_HOUR.
2135 2136 2137 2138 2139 2140 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2135 class PartitionField < Struct.new( :transform, :source_name) SENSITIVE = [] include Aws::Structure end |