Class: Aws::Kinesis::Types::S3DestinationDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::S3DestinationDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The configuration for delivery to a general purpose Amazon S3 bucket. Returned in ChannelDescription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
-
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
-
#storage_configuration ⇒ Types::S3StorageConfiguration
The Amazon S3 storage configuration for the channel.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
2675 2676 2677 2678 2679 2680 2681 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2675 class S3DestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
2675 2676 2677 2678 2679 2680 2681 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2675 class S3DestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#storage_configuration ⇒ Types::S3StorageConfiguration
The Amazon S3 storage configuration for the channel.
2675 2676 2677 2678 2679 2680 2681 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2675 class S3DestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |