Class: Aws::Kinesis::Types::S3TablesDestinationDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::S3TablesDestinationDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The configuration for delivery to streaming tables on Apache Iceberg. Returned in ChannelDescription.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
-
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
-
#s3_tables_configuration_list ⇒ Array<Types::S3TablesConfiguration>
The list of streaming table configurations.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2836 class S3TablesDestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2836 class S3TablesDestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |
#s3_tables_configuration_list ⇒ Array<Types::S3TablesConfiguration>
The list of streaming table configurations.
2836 2837 2838 2839 2840 2841 2842 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2836 class S3TablesDestinationDescription < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |