Class: Aws::Kinesis::Types::SplitShardInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the input for SplitShard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#new_starting_hash_keyString

A hash key value for the starting hash key of one of the child shards created by the split. The hash key range for a given shard constitutes a set of ordered contiguous positive integers. The value for NewStartingHashKey must be in the range of hash keys being mapped into the shard. The NewStartingHashKey hash key value and all higher hash key values in hash key range are distributed to one of the child shards. All the lower hash key values in the range are distributed to the other child shard.

Returns:

  • (String)


3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/aws-sdk-kinesis/types.rb', line 3004

class SplitShardInput < Struct.new(
  :stream_name,
  :shard_to_split,
  :new_starting_hash_key,
  :stream_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#shard_to_splitString

The shard ID of the shard to split.

Returns:

  • (String)


3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/aws-sdk-kinesis/types.rb', line 3004

class SplitShardInput < Struct.new(
  :stream_name,
  :shard_to_split,
  :new_starting_hash_key,
  :stream_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The ARN of the stream.

Returns:

  • (String)


3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/aws-sdk-kinesis/types.rb', line 3004

class SplitShardInput < Struct.new(
  :stream_name,
  :shard_to_split,
  :new_starting_hash_key,
  :stream_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/aws-sdk-kinesis/types.rb', line 3004

class SplitShardInput < Struct.new(
  :stream_name,
  :shard_to_split,
  :new_starting_hash_key,
  :stream_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the stream for the shard split.

Returns:

  • (String)


3004
3005
3006
3007
3008
3009
3010
3011
3012
# File 'lib/aws-sdk-kinesis/types.rb', line 3004

class SplitShardInput < Struct.new(
  :stream_name,
  :shard_to_split,
  :new_starting_hash_key,
  :stream_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end