Class: Aws::Kinesis::Types::StopStreamEncryptionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::StopStreamEncryptionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The encryption type.
-
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use for encryption.
-
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the stream on which to stop encrypting records.
Instance Attribute Details
#encryption_type ⇒ String
The encryption type. The only valid value is KMS.
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2356 class StopStreamEncryptionInput < Struct.new( :stream_name, :encryption_type, :key_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use for encryption. This value can be a globally unique identifier, a fully specified Amazon Resource Name (ARN) to either an alias or a key, or an alias name prefixed by “alias/”.You can also use a master key owned by Kinesis Data Streams by specifying the alias aws/kinesis.
-
Key ARN example:
arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012 -
Alias ARN example:
arn:aws:kms:us-east-1:123456789012:alias/MyAliasName -
Globally unique key ID example:
12345678-1234-1234-1234-123456789012 -
Alias name example:
alias/MyAliasName -
Master key owned by Kinesis Data Streams:
alias/aws/kinesis
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2356 class StopStreamEncryptionInput < Struct.new( :stream_name, :encryption_type, :key_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2356 class StopStreamEncryptionInput < Struct.new( :stream_name, :encryption_type, :key_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2356 class StopStreamEncryptionInput < Struct.new( :stream_name, :encryption_type, :key_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream on which to stop encrypting records.
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2356 class StopStreamEncryptionInput < Struct.new( :stream_name, :encryption_type, :key_id, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |