Class: Aws::Kinesis::Types::StreamDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::StreamDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the output for DescribeStream.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The server-side encryption type used on the stream.
-
#enhanced_monitoring ⇒ Array<Types::EnhancedMetrics>
Represents the current enhanced monitoring settings of the stream.
-
#has_more_shards ⇒ Boolean
If set to
true, more shards in the stream are available to describe. -
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use for encryption.
-
#retention_period_hours ⇒ Integer
The current retention period, in hours.
-
#shards ⇒ Array<Types::Shard>
The shards that comprise the stream.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) for the stream being described.
-
#stream_creation_timestamp ⇒ Time
The approximate time that the stream was created.
-
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream.
-
#stream_name ⇒ String
The name of the stream being described.
-
#stream_status ⇒ String
The current status of the stream being described.
Instance Attribute Details
#encryption_type ⇒ String
The server-side encryption type used on the stream. This parameter can be one of the following values:
-
NONE: Do not encrypt the records in the stream. -
KMS: Use server-side encryption on the records in the stream using a customer-managed Amazon Web Services KMS key.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ Array<Types::EnhancedMetrics>
Represents the current enhanced monitoring settings of the stream.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#has_more_shards ⇒ Boolean
If set to true, more shards in the stream are available to
describe.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use
for encryption. This value can be a globally unique identifier, a
fully specified ARN to either an alias or a key, or an alias name
prefixed by "alias/".You can also use a master key owned by
Kinesis Data Streams by specifying the alias aws/kinesis.
-
Key ARN example:
arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012 -
Alias ARN example:
arn:aws:kms:us-east-1:123456789012:alias/MyAliasName -
Globally unique key ID example:
12345678-1234-1234-1234-123456789012 -
Alias name example:
alias/MyAliasName -
Master key owned by Kinesis Data Streams:
alias/aws/kinesis
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#retention_period_hours ⇒ Integer
The current retention period, in hours. Minimum value of 24. Maximum value of 168.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#shards ⇒ Array<Types::Shard>
The shards that comprise the stream.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) for the stream being described.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#stream_creation_timestamp ⇒ Time
The approximate time that the stream was created.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand capacity mode and a provisioned capacity mode for your data streams.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream being described.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#stream_status ⇒ String
The current status of the stream being described. The stream status is one of the following states:
-
CREATING- The stream is being created. Kinesis Data Streams immediately returns and setsStreamStatustoCREATING. -
DELETING- The stream is being deleted. The specified stream is in theDELETINGstate until Kinesis Data Streams completes the deletion. -
ACTIVE- The stream exists and is ready for read and write operations or deletion. You should perform read and write operations only on anACTIVEstream. -
UPDATING- Shards in the stream are being merged or split. Read and write operations continue to work while the stream is in theUPDATINGstate.
3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3257 class StreamDescription < Struct.new( :stream_name, :stream_arn, :stream_status, :stream_mode_details, :shards, :has_more_shards, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |