Class: Aws::Kinesis::Types::StreamDescriptionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the output for DescribeStreamSummary

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_countInteger

The number of channels associated with the stream.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#consumer_countInteger

The number of enhanced fan-out consumers registered with the stream.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_typeString

The encryption type used. This value is one of the following:

  • KMS

  • NONE



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_monitoringArray<Types::EnhancedMetrics>

Represents the current enhanced monitoring settings of the stream.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#key_idString

The GUID for the customer-managed Amazon Web Services KMS key to use for encryption. This value can be a globally unique identifier, a fully specified ARN to either an alias or a key, or an alias name prefixed by "alias/".You can also use a master key owned by Kinesis Data Streams by specifying the alias aws/kinesis.

  • Key ARN example: arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012

  • Alias ARN example: arn:aws:kms:us-east-1:123456789012:alias/MyAliasName

  • Globally unique key ID example: 12345678-1234-1234-1234-123456789012

  • Alias name example: alias/MyAliasName

  • Master key owned by Kinesis Data Streams: alias/aws/kinesis



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#max_record_size_in_ki_bInteger

The maximum record size of a single record in kibibyte (KiB) that you can write to, and read from a stream.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#open_shard_countInteger

The number of open shards in the stream.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#retention_period_hoursInteger

The current retention period, in hours.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The Amazon Resource Name (ARN) for the stream being described.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_creation_timestampTime

The approximate time that the stream was created.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_mode_detailsTypes::StreamModeDetails

Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand ycapacity mode and a provisioned capacity mode for your data streams.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the stream being described.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#stream_statusString

The current status of the stream being described. The stream status is one of the following states:

  • CREATING - The stream is being created. Kinesis Data Streams immediately returns and sets StreamStatus to CREATING.

  • DELETING - The stream is being deleted. The specified stream is in the DELETING state until Kinesis Data Streams completes the deletion.

  • ACTIVE - The stream exists and is ready for read and write operations or deletion. You should perform read and write operations only on an ACTIVE stream.

  • UPDATING - Shards in the stream are being merged or split. Read and write operations continue to work while the stream is in the UPDATING state.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end

#warm_throughputTypes::WarmThroughputObject

The warm throughput in MB/s for the stream. This represents the throughput capacity that will be immediately available for write operations.



3421
3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
# File 'lib/aws-sdk-kinesis/types.rb', line 3421

class StreamDescriptionSummary < Struct.new(
  :stream_name,
  :stream_arn,
  :stream_id,
  :stream_status,
  :stream_mode_details,
  :retention_period_hours,
  :stream_creation_timestamp,
  :enhanced_monitoring,
  :encryption_type,
  :key_id,
  :open_shard_count,
  :consumer_count,
  :warm_throughput,
  :max_record_size_in_ki_b,
  :channel_count)
  SENSITIVE = []
  include Aws::Structure
end