Class: Aws::Kinesis::Types::SubscribeToShardInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#consumer_arnString

For this parameter, use the value you obtained when you called RegisterStreamConsumer.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
# File 'lib/aws-sdk-kinesis/types.rb', line 3535

class SubscribeToShardInput < Struct.new(
  :consumer_arn,
  :stream_id,
  :shard_id,
  :starting_position)
  SENSITIVE = []
  include Aws::Structure
end

#shard_idString

The ID of the shard you want to subscribe to. To see a list of all the shards for a given stream, use ListShards.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
# File 'lib/aws-sdk-kinesis/types.rb', line 3535

class SubscribeToShardInput < Struct.new(
  :consumer_arn,
  :stream_id,
  :shard_id,
  :starting_position)
  SENSITIVE = []
  include Aws::Structure
end

#starting_positionTypes::StartingPosition

The starting position in the data stream from which to start streaming.



3535
3536
3537
3538
3539
3540
3541
3542
# File 'lib/aws-sdk-kinesis/types.rb', line 3535

class SubscribeToShardInput < Struct.new(
  :consumer_arn,
  :stream_id,
  :shard_id,
  :starting_position)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


3535
3536
3537
3538
3539
3540
3541
3542
# File 'lib/aws-sdk-kinesis/types.rb', line 3535

class SubscribeToShardInput < Struct.new(
  :consumer_arn,
  :stream_id,
  :shard_id,
  :starting_position)
  SENSITIVE = []
  include Aws::Structure
end