Class: Aws::Kinesis::Types::UpdateChannelInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::UpdateChannelInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The Amazon Resource Name (ARN) of the channel to update.
-
#logging_configuration ⇒ Types::ChannelLoggingUpdateInput
The updated Amazon CloudWatch Logs configuration for the channel.
-
#s3_destination_configuration ⇒ Types::S3DestinationUpdateInput
The updated configuration for a general purpose Amazon S3 destination.
-
#s3_tables_destination_configuration ⇒ Types::S3TablesDestinationUpdateInput
The updated configuration for a streaming table destination.
Instance Attribute Details
#channel_arn ⇒ String
The Amazon Resource Name (ARN) of the channel to update.
3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3680 class UpdateChannelInput < Struct.new( :channel_arn, :s3_destination_configuration, :s3_tables_destination_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ChannelLoggingUpdateInput
The updated Amazon CloudWatch Logs configuration for the channel.
3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3680 class UpdateChannelInput < Struct.new( :channel_arn, :s3_destination_configuration, :s3_tables_destination_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_destination_configuration ⇒ Types::S3DestinationUpdateInput
The updated configuration for a general purpose Amazon S3
destination. Only DataFreshnessInSeconds can be updated.
3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3680 class UpdateChannelInput < Struct.new( :channel_arn, :s3_destination_configuration, :s3_tables_destination_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#s3_tables_destination_configuration ⇒ Types::S3TablesDestinationUpdateInput
The updated configuration for a streaming table destination. Only
DataFreshnessInSeconds can be updated.
3680 3681 3682 3683 3684 3685 3686 3687 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3680 class UpdateChannelInput < Struct.new( :channel_arn, :s3_destination_configuration, :s3_tables_destination_configuration, :logging_configuration) SENSITIVE = [] include Aws::Structure end |