Class: Aws::Kinesis::Types::UpdateChannelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::UpdateChannelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_description ⇒ Types::ChannelDescription
The configuration and current status of the updated channel.
Instance Attribute Details
#channel_description ⇒ Types::ChannelDescription
The configuration and current status of the updated channel.
3695 3696 3697 3698 3699 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3695 class UpdateChannelOutput < Struct.new( :channel_description) SENSITIVE = [] include Aws::Structure end |