Class: Aws::Kinesis::Types::UpdateStreamModeInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stream_arnString

Specifies the ARN of the data stream whose capacity mode you want to update.

Returns:

  • (String)


3824
3825
3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-kinesis/types.rb', line 3824

class UpdateStreamModeInput < Struct.new(
  :stream_arn,
  :stream_id,
  :stream_mode_details,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


3824
3825
3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-kinesis/types.rb', line 3824

class UpdateStreamModeInput < Struct.new(
  :stream_arn,
  :stream_id,
  :stream_mode_details,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#stream_mode_detailsTypes::StreamModeDetails

Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand capacity mode and a provisioned capacity mode for your data streams.



3824
3825
3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-kinesis/types.rb', line 3824

class UpdateStreamModeInput < Struct.new(
  :stream_arn,
  :stream_id,
  :stream_mode_details,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#warm_throughput_mi_bpsInteger

The target warm throughput in MB/s that the stream should be scaled to handle. This represents the throughput capacity that will be immediately available for write operations. This field is only valid when the stream mode is being updated to on-demand.

Returns:

  • (Integer)


3824
3825
3826
3827
3828
3829
3830
3831
# File 'lib/aws-sdk-kinesis/types.rb', line 3824

class UpdateStreamModeInput < Struct.new(
  :stream_arn,
  :stream_id,
  :stream_mode_details,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end