Class: Aws::Kinesis::Types::UpdateStreamWarmThroughputInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stream_arnString

The ARN of the stream to be updated.

Returns:

  • (String)


3853
3854
3855
3856
3857
3858
3859
3860
# File 'lib/aws-sdk-kinesis/types.rb', line 3853

class UpdateStreamWarmThroughputInput < Struct.new(
  :stream_arn,
  :stream_name,
  :stream_id,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Not Implemented. Reserved for future use.

Returns:

  • (String)


3853
3854
3855
3856
3857
3858
3859
3860
# File 'lib/aws-sdk-kinesis/types.rb', line 3853

class UpdateStreamWarmThroughputInput < Struct.new(
  :stream_arn,
  :stream_name,
  :stream_id,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the stream to be updated.

Returns:

  • (String)


3853
3854
3855
3856
3857
3858
3859
3860
# File 'lib/aws-sdk-kinesis/types.rb', line 3853

class UpdateStreamWarmThroughputInput < Struct.new(
  :stream_arn,
  :stream_name,
  :stream_id,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#warm_throughput_mi_bpsInteger

The target warm throughput in MB/s that the stream should be scaled to handle. This represents the throughput capacity that will be immediately available for write operations.

Returns:

  • (Integer)


3853
3854
3855
3856
3857
3858
3859
3860
# File 'lib/aws-sdk-kinesis/types.rb', line 3853

class UpdateStreamWarmThroughputInput < Struct.new(
  :stream_arn,
  :stream_name,
  :stream_id,
  :warm_throughput_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end