Class: Aws::Kinesis::Types::WarmThroughputObject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

Represents the warm throughput configuration on the stream. This is only present for On-Demand Kinesis Data Streams in accounts that have MinimumThroughputBillingCommitment enabled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_mi_bpsInteger

The current warm throughput value on the stream. This is the write throughput in MiBps that the stream is currently scaled to handle.

Returns:

  • (Integer)


3916
3917
3918
3919
3920
3921
# File 'lib/aws-sdk-kinesis/types.rb', line 3916

class WarmThroughputObject < Struct.new(
  :target_mi_bps,
  :current_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end

#target_mi_bpsInteger

The target warm throughput value on the stream. This indicates that the stream is currently scaling towards this target value.

Returns:

  • (Integer)


3916
3917
3918
3919
3920
3921
# File 'lib/aws-sdk-kinesis/types.rb', line 3916

class WarmThroughputObject < Struct.new(
  :target_mi_bps,
  :current_mi_bps)
  SENSITIVE = []
  include Aws::Structure
end