Class: Aws::Kinesis::Types::ChannelEncryptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ChannelEncryptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The server-side encryption configuration for a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_type ⇒ String
The encryption type.
-
#key_id ⇒ String
The identifier of the customer managed Amazon Web Services KMS key.
Instance Attribute Details
#encryption_type ⇒ String
The encryption type. The only valid value is KMS.
156 157 158 159 160 161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 156 class ChannelEncryptionConfiguration < Struct.new( :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The identifier of the customer managed Amazon Web Services KMS key.
You cannot use the Amazon Kinesis Data Streams service key
(aws/kinesis).
156 157 158 159 160 161 |
# File 'lib/aws-sdk-kinesis/types.rb', line 156 class ChannelEncryptionConfiguration < Struct.new( :encryption_type, :key_id) SENSITIVE = [] include Aws::Structure end |