Class: Aws::Kinesis::Types::ConsumerDescription
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ConsumerDescription
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
An object that represents the details of a registered consumer. This type of object is returned by DescribeStreamConsumer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_arn ⇒ String
When you register a consumer, Kinesis Data Streams generates an ARN for it.
- #consumer_creation_timestamp ⇒ Time
-
#consumer_name ⇒ String
The name of the consumer is something you choose when you register the consumer.
-
#consumer_status ⇒ String
A consumer can't read data while in the
CREATINGorDELETINGstates. -
#stream_arn ⇒ String
The ARN of the stream with which you registered the consumer.
Instance Attribute Details
#consumer_arn ⇒ String
When you register a consumer, Kinesis Data Streams generates an ARN for it. You need this ARN to be able to call SubscribeToShard.
If you delete a consumer and then create a new one with the same name, it won't have the same ARN. That's because consumer ARNs contain the creation timestamp. This is important to keep in mind if you have IAM policies that reference consumer ARNs.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-kinesis/types.rb', line 463 class ConsumerDescription < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#consumer_creation_timestamp ⇒ Time
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-kinesis/types.rb', line 463 class ConsumerDescription < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#consumer_name ⇒ String
The name of the consumer is something you choose when you register the consumer.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-kinesis/types.rb', line 463 class ConsumerDescription < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#consumer_status ⇒ String
A consumer can't read data while in the CREATING or DELETING
states.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-kinesis/types.rb', line 463 class ConsumerDescription < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp, :stream_arn) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream with which you registered the consumer.
463 464 465 466 467 468 469 470 471 |
# File 'lib/aws-sdk-kinesis/types.rb', line 463 class ConsumerDescription < Struct.new( :consumer_name, :consumer_arn, :consumer_status, :consumer_creation_timestamp, :stream_arn) SENSITIVE = [] include Aws::Structure end |