Class: Aws::Kinesis::Types::DescribeStreamConsumerInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::DescribeStreamConsumerInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#consumer_arn ⇒ String
The ARN returned by Kinesis Data Streams when you registered the consumer.
-
#consumer_name ⇒ String
The name that you gave to the consumer.
-
#stream_arn ⇒ String
The ARN of the Kinesis data stream that the consumer is registered with.
-
#stream_id ⇒ String
Not Implemented.
Instance Attribute Details
#consumer_arn ⇒ String
The ARN returned by Kinesis Data Streams when you registered the consumer.
862 863 864 865 866 867 868 869 |
# File 'lib/aws-sdk-kinesis/types.rb', line 862 class DescribeStreamConsumerInput < Struct.new( :stream_arn, :consumer_name, :consumer_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#consumer_name ⇒ String
The name that you gave to the consumer.
862 863 864 865 866 867 868 869 |
# File 'lib/aws-sdk-kinesis/types.rb', line 862 class DescribeStreamConsumerInput < Struct.new( :stream_arn, :consumer_name, :consumer_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the Kinesis data stream that the consumer is registered with. For more information, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces.
862 863 864 865 866 867 868 869 |
# File 'lib/aws-sdk-kinesis/types.rb', line 862 class DescribeStreamConsumerInput < Struct.new( :stream_arn, :consumer_name, :consumer_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
862 863 864 865 866 867 868 869 |
# File 'lib/aws-sdk-kinesis/types.rb', line 862 class DescribeStreamConsumerInput < Struct.new( :stream_arn, :consumer_name, :consumer_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |