Class: Aws::Kinesis::Types::DisableEnhancedMonitoringInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::DisableEnhancedMonitoringInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the input for DisableEnhancedMonitoring.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics to disable.
-
#stream_arn ⇒ String
The ARN of the stream.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_name ⇒ String
The name of the Kinesis data stream for which to disable enhanced monitoring.
Instance Attribute Details
#shard_level_metrics ⇒ Array<String>
List of shard-level metrics to disable.
The following are the valid shard-level metrics. The value "ALL"
disables every metric.
-
IncomingBytes -
IncomingRecords -
OutgoingBytes -
OutgoingRecords -
WriteProvisionedThroughputExceeded -
ReadProvisionedThroughputExceeded -
IteratorAgeMilliseconds -
ALL
For more information, see Monitoring the Amazon Kinesis Data Streams Service with Amazon CloudWatch in the Amazon Kinesis Data Streams Developer Guide.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1025 class DisableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The ARN of the stream.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1025 class DisableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1025 class DisableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the Kinesis data stream for which to disable enhanced monitoring.
1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1025 class DisableEnhancedMonitoringInput < Struct.new( :stream_name, :shard_level_metrics, :stream_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |