Class: Aws::Kinesis::Types::ListChannelsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::ListChannelsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_summaries ⇒ Array<Types::ChannelSummary>
A list of channel summaries.
-
#next_token ⇒ String
The pagination token to use in a subsequent call to retrieve the next page of results.
Instance Attribute Details
#channel_summaries ⇒ Array<Types::ChannelSummary>
A list of channel summaries.
1647 1648 1649 1650 1651 1652 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1647 class ListChannelsOutput < Struct.new( :channel_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token to use in a subsequent call to retrieve the
next page of results. This value is null when there are no more
results to return.
1647 1648 1649 1650 1651 1652 |
# File 'lib/aws-sdk-kinesis/types.rb', line 1647 class ListChannelsOutput < Struct.new( :channel_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |