Class: Aws::Kinesis::Types::S3DestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::S3DestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The configuration for delivery to a general purpose Amazon S3 bucket. Used in CreateChannel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
-
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
-
#storage_configuration ⇒ Types::S3StorageConfiguration
The Amazon S3 storage configuration for the channel.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data. Valid range is 300 to 900 seconds (5 to 15 minutes). The default value is 300 seconds.
2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2649 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered. Optional for general purpose Amazon S3 destinations. If not specified, it defaults to the destination bucket with an error prefix.
2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2649 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#storage_configuration ⇒ Types::S3StorageConfiguration
The Amazon S3 storage configuration for the channel.
2649 2650 2651 2652 2653 2654 2655 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2649 class S3DestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |