Class: Aws::Kinesis::Types::S3StorageConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesis/types.rb

Overview

The Amazon S3 storage settings for a general purpose Amazon S3 destination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_arnString

The Amazon Resource Name (ARN) of the destination Amazon S3 bucket.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/aws-sdk-kinesis/types.rb', line 2739

class S3StorageConfiguration < Struct.new(
  :bucket_arn,
  :expected_bucket_owner,
  :output_key_template,
  :storage_class,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#compression_typeString

The compression applied to delivered objects. Valid values:

  • NONE - No compression.

  • GZIP - gzip compression.

  • ZSTD - Zstandard compression.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/aws-sdk-kinesis/types.rb', line 2739

class S3StorageConfiguration < Struct.new(
  :bucket_arn,
  :expected_bucket_owner,
  :output_key_template,
  :storage_class,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID of the expected owner of the destination bucket. This value helps prevent delivery to an unintended bucket if ownership changes.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/aws-sdk-kinesis/types.rb', line 2739

class S3StorageConfiguration < Struct.new(
  :bucket_arn,
  :expected_bucket_owner,
  :output_key_template,
  :storage_class,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#output_key_templateString

The template used to construct the Amazon S3 object key for delivered objects. If not specified, a default template is used.

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/aws-sdk-kinesis/types.rb', line 2739

class S3StorageConfiguration < Struct.new(
  :bucket_arn,
  :expected_bucket_owner,
  :output_key_template,
  :storage_class,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_classString

The Amazon S3 storage class for delivered objects. Valid values:

  • STANDARD (default)

  • INTELLIGENT_TIERING

  • GLACIER_IR

Returns:

  • (String)


2739
2740
2741
2742
2743
2744
2745
2746
2747
# File 'lib/aws-sdk-kinesis/types.rb', line 2739

class S3StorageConfiguration < Struct.new(
  :bucket_arn,
  :expected_bucket_owner,
  :output_key_template,
  :storage_class,
  :compression_type)
  SENSITIVE = []
  include Aws::Structure
end