Class: Aws::Kinesis::Types::S3StorageConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::S3StorageConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The Amazon S3 storage settings for a general purpose Amazon S3 destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the destination Amazon S3 bucket.
-
#compression_type ⇒ String
The compression applied to delivered objects.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID of the expected owner of the destination bucket.
-
#output_key_template ⇒ String
The template used to construct the Amazon S3 object key for delivered objects.
-
#storage_class ⇒ String
The Amazon S3 storage class for delivered objects.
Instance Attribute Details
#bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the destination Amazon S3 bucket.
2739 2740 2741 2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2739 class S3StorageConfiguration < Struct.new( :bucket_arn, :expected_bucket_owner, :output_key_template, :storage_class, :compression_type) SENSITIVE = [] include Aws::Structure end |
#compression_type ⇒ String
The compression applied to delivered objects. Valid values:
-
NONE- No compression. -
GZIP- gzip compression. -
ZSTD- Zstandard compression.
2739 2740 2741 2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2739 class S3StorageConfiguration < Struct.new( :bucket_arn, :expected_bucket_owner, :output_key_template, :storage_class, :compression_type) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID of the expected owner of the destination bucket. This value helps prevent delivery to an unintended bucket if ownership changes.
2739 2740 2741 2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2739 class S3StorageConfiguration < Struct.new( :bucket_arn, :expected_bucket_owner, :output_key_template, :storage_class, :compression_type) SENSITIVE = [] include Aws::Structure end |
#output_key_template ⇒ String
The template used to construct the Amazon S3 object key for delivered objects. If not specified, a default template is used.
2739 2740 2741 2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2739 class S3StorageConfiguration < Struct.new( :bucket_arn, :expected_bucket_owner, :output_key_template, :storage_class, :compression_type) SENSITIVE = [] include Aws::Structure end |
#storage_class ⇒ String
The Amazon S3 storage class for delivered objects. Valid values:
-
STANDARD(default) -
INTELLIGENT_TIERING -
GLACIER_IR
2739 2740 2741 2742 2743 2744 2745 2746 2747 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2739 class S3StorageConfiguration < Struct.new( :bucket_arn, :expected_bucket_owner, :output_key_template, :storage_class, :compression_type) SENSITIVE = [] include Aws::Structure end |