Class: Aws::Kinesis::Types::S3TablesDestinationConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::S3TablesDestinationConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
The configuration for delivery to streaming tables on Apache Iceberg. Used in CreateChannel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data.
-
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered.
-
#s3_tables_configuration_list ⇒ Array<Types::S3TablesConfiguration>
The list of streaming table configurations.
Instance Attribute Details
#data_freshness_in_seconds ⇒ Integer
The maximum age, in seconds, of undelivered data. Valid range is 300 to 900 seconds (5 to 15 minutes). The default value is 300 seconds.
2810 2811 2812 2813 2814 2815 2816 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2810 class S3TablesDestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |
#dead_letter_queue_s3_configuration ⇒ Types::DeadLetterQueueS3Configuration
The dead-letter queue configuration for records that cannot be delivered. Required for streaming table destinations.
2810 2811 2812 2813 2814 2815 2816 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2810 class S3TablesDestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |
#s3_tables_configuration_list ⇒ Array<Types::S3TablesConfiguration>
The list of streaming table configurations. Currently, one table is supported per channel.
2810 2811 2812 2813 2814 2815 2816 |
# File 'lib/aws-sdk-kinesis/types.rb', line 2810 class S3TablesDestinationConfiguration < Struct.new( :data_freshness_in_seconds, :dead_letter_queue_s3_configuration, :s3_tables_configuration_list) SENSITIVE = [] include Aws::Structure end |