Class: Aws::Kinesis::Types::StreamDescriptionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::StreamDescriptionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Represents the output for DescribeStreamSummary
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_count ⇒ Integer
The number of channels associated with the stream.
-
#consumer_count ⇒ Integer
The number of enhanced fan-out consumers registered with the stream.
-
#encryption_type ⇒ String
The encryption type used.
-
#enhanced_monitoring ⇒ Array<Types::EnhancedMetrics>
Represents the current enhanced monitoring settings of the stream.
-
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use for encryption.
-
#max_record_size_in_ki_b ⇒ Integer
The maximum record size of a single record in kibibyte (KiB) that you can write to, and read from a stream.
-
#open_shard_count ⇒ Integer
The number of open shards in the stream.
-
#retention_period_hours ⇒ Integer
The current retention period, in hours.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) for the stream being described.
-
#stream_creation_timestamp ⇒ Time
The approximate time that the stream was created.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream.
-
#stream_name ⇒ String
The name of the stream being described.
-
#stream_status ⇒ String
The current status of the stream being described.
-
#warm_throughput ⇒ Types::WarmThroughputObject
The warm throughput in MB/s for the stream.
Instance Attribute Details
#channel_count ⇒ Integer
The number of channels associated with the stream.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#consumer_count ⇒ Integer
The number of enhanced fan-out consumers registered with the stream.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#encryption_type ⇒ String
The encryption type used. This value is one of the following:
-
KMS -
NONE
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#enhanced_monitoring ⇒ Array<Types::EnhancedMetrics>
Represents the current enhanced monitoring settings of the stream.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#key_id ⇒ String
The GUID for the customer-managed Amazon Web Services KMS key to use
for encryption. This value can be a globally unique identifier, a
fully specified ARN to either an alias or a key, or an alias name
prefixed by "alias/".You can also use a master key owned by
Kinesis Data Streams by specifying the alias aws/kinesis.
-
Key ARN example:
arn:aws:kms:us-east-1:123456789012:key/12345678-1234-1234-1234-123456789012 -
Alias ARN example:
arn:aws:kms:us-east-1:123456789012:alias/MyAliasName -
Globally unique key ID example:
12345678-1234-1234-1234-123456789012 -
Alias name example:
alias/MyAliasName -
Master key owned by Kinesis Data Streams:
alias/aws/kinesis
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#max_record_size_in_ki_b ⇒ Integer
The maximum record size of a single record in kibibyte (KiB) that you can write to, and read from a stream.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#open_shard_count ⇒ Integer
The number of open shards in the stream.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#retention_period_hours ⇒ Integer
The current retention period, in hours.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) for the stream being described.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_creation_timestamp ⇒ Time
The approximate time that the stream was created.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand ycapacity mode and a provisioned capacity mode for your data streams.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream being described.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#stream_status ⇒ String
The current status of the stream being described. The stream status is one of the following states:
-
CREATING- The stream is being created. Kinesis Data Streams immediately returns and setsStreamStatustoCREATING. -
DELETING- The stream is being deleted. The specified stream is in theDELETINGstate until Kinesis Data Streams completes the deletion. -
ACTIVE- The stream exists and is ready for read and write operations or deletion. You should perform read and write operations only on anACTIVEstream. -
UPDATING- Shards in the stream are being merged or split. Read and write operations continue to work while the stream is in theUPDATINGstate.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |
#warm_throughput ⇒ Types::WarmThroughputObject
The warm throughput in MB/s for the stream. This represents the throughput capacity that will be immediately available for write operations.
3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3380 class StreamDescriptionSummary < Struct.new( :stream_name, :stream_arn, :stream_id, :stream_status, :stream_mode_details, :retention_period_hours, :stream_creation_timestamp, :enhanced_monitoring, :encryption_type, :key_id, :open_shard_count, :consumer_count, :warm_throughput, :max_record_size_in_ki_b, :channel_count) SENSITIVE = [] include Aws::Structure end |