Class: Aws::Kinesis::Types::UpdateStreamModeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Kinesis::Types::UpdateStreamModeInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesis/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stream_arn ⇒ String
Specifies the ARN of the data stream whose capacity mode you want to update.
-
#stream_id ⇒ String
Not Implemented.
-
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream.
-
#warm_throughput_mi_bps ⇒ Integer
The target warm throughput in MB/s that the stream should be scaled to handle.
Instance Attribute Details
#stream_arn ⇒ String
Specifies the ARN of the data stream whose capacity mode you want to update.
3824 3825 3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3824 class UpdateStreamModeInput < Struct.new( :stream_arn, :stream_id, :stream_mode_details, :warm_throughput_mi_bps) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Not Implemented. Reserved for future use.
3824 3825 3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3824 class UpdateStreamModeInput < Struct.new( :stream_arn, :stream_id, :stream_mode_details, :warm_throughput_mi_bps) SENSITIVE = [] include Aws::Structure end |
#stream_mode_details ⇒ Types::StreamModeDetails
Specifies the capacity mode to which you want to set your data stream. Currently, in Kinesis Data Streams, you can choose between an on-demand capacity mode and a provisioned capacity mode for your data streams.
3824 3825 3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3824 class UpdateStreamModeInput < Struct.new( :stream_arn, :stream_id, :stream_mode_details, :warm_throughput_mi_bps) SENSITIVE = [] include Aws::Structure end |
#warm_throughput_mi_bps ⇒ Integer
The target warm throughput in MB/s that the stream should be scaled to handle. This represents the throughput capacity that will be immediately available for write operations. This field is only valid when the stream mode is being updated to on-demand.
3824 3825 3826 3827 3828 3829 3830 3831 |
# File 'lib/aws-sdk-kinesis/types.rb', line 3824 class UpdateStreamModeInput < Struct.new( :stream_arn, :stream_id, :stream_mode_details, :warm_throughput_mi_bps) SENSITIVE = [] include Aws::Structure end |